@@ -347,7 +347,7 @@ pub fn inner_raw_sign<T: SigningTranscript>(secret: SecretKey, mut t: T, r_point
     t.commit_point(b"sign:pk",public.as_compressed());
 
     let r_compress = r_point.as_compressed();
-    t.commit_point(b"sign:r_compress",&r_compress);
+    t.commit_point(b"sign:R",&r_compress);
 
     let e = t.challenge_scalar(b"sign:c");  // context, message, A/public_key, R=rG
 
